package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.projectV2.ZsyzSkSwtzdw;
import com.ruoyi.system.mapper.projectV2.ZsyzSkSwtzdwMapper;
import com.ruoyi.system.service.projectV2.IZsyzSkSwtzdwService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 招商引资_省库项目_省外投资单位Service业务层处理
 * 
 * @author boman
 * @date 2023-03-28
 */
@Service
public class ZsyzSkSwtzdwServiceImpl implements IZsyzSkSwtzdwService
{
    @Autowired
    private ZsyzSkSwtzdwMapper zsyzSkSwtzdwMapper;

    /**
     * 查询招商引资_省库项目_省外投资单位
     * 
     * @param id 招商引资_省库项目_省外投资单位主键
     * @return 招商引资_省库项目_省外投资单位
     */
    @Override
    public ZsyzSkSwtzdw selectZsyzSkSwtzdwById(Long id)
    {
        return zsyzSkSwtzdwMapper.selectZsyzSkSwtzdwById(id);
    }

    /**
     * 查询招商引资_省库项目_省外投资单位列表
     * 
     * @param zsyzSkSwtzdw 招商引资_省库项目_省外投资单位
     * @return 招商引资_省库项目_省外投资单位
     */
    @Override
    public List<ZsyzSkSwtzdw> selectZsyzSkSwtzdwList(ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        return zsyzSkSwtzdwMapper.selectZsyzSkSwtzdwList(zsyzSkSwtzdw);
    }

    /**
     * 新增招商引资_省库项目_省外投资单位
     * 
     * @param zsyzSkSwtzdw 招商引资_省库项目_省外投资单位
     * @return 结果
     */
    @Override
    public int insertZsyzSkSwtzdw(ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        zsyzSkSwtzdw.setCreateTime(DateUtils.getNowDate());
        return zsyzSkSwtzdwMapper.insertZsyzSkSwtzdw(zsyzSkSwtzdw);
    }

    /**
     * 修改招商引资_省库项目_省外投资单位
     * 
     * @param zsyzSkSwtzdw 招商引资_省库项目_省外投资单位
     * @return 结果
     */
    @Override
    public int updateZsyzSkSwtzdw(ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        zsyzSkSwtzdw.setUpdateTime(DateUtils.getNowDate());
        return zsyzSkSwtzdwMapper.updateZsyzSkSwtzdw(zsyzSkSwtzdw);
    }

    /**
     * 批量删除招商引资_省库项目_省外投资单位
     * 
     * @param ids 需要删除的招商引资_省库项目_省外投资单位主键
     * @return 结果
     */
    @Override
    public int deleteZsyzSkSwtzdwByIds(Long[] ids)
    {
        return zsyzSkSwtzdwMapper.deleteZsyzSkSwtzdwByIds(ids);
    }

    /**
     * 删除招商引资_省库项目_省外投资单位信息
     * 
     * @param id 招商引资_省库项目_省外投资单位主键
     * @return 结果
     */
    @Override
    public int deleteZsyzSkSwtzdwById(Long id)
    {
        return zsyzSkSwtzdwMapper.deleteZsyzSkSwtzdwById(id);
    }
}
