package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzSkSwtzdw;
import com.ruoyi.system.service.projectV2.IZsyzSkSwtzdwService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_省库项目_省外投资单位Controller
 * 
 * @author boman
 * @date 2023-03-28
 */
@RestController
@RequestMapping("/projectV2/swtzdw")
public class ZsyzSkSwtzdwController extends BaseController
{
    @Autowired
    private IZsyzSkSwtzdwService zsyzSkSwtzdwService;

    /**
     * 查询招商引资_省库项目_省外投资单位列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        startPage();
        List<ZsyzSkSwtzdw> list = zsyzSkSwtzdwService.selectZsyzSkSwtzdwList(zsyzSkSwtzdw);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_省库项目_省外投资单位列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:export')")
    @Log(title = "招商引资_省库项目_省外投资单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        List<ZsyzSkSwtzdw> list = zsyzSkSwtzdwService.selectZsyzSkSwtzdwList(zsyzSkSwtzdw);
        ExcelUtil<ZsyzSkSwtzdw> util = new ExcelUtil<ZsyzSkSwtzdw>(ZsyzSkSwtzdw.class);
        util.exportExcel(response, list, "招商引资_省库项目_省外投资单位数据");
    }

    /**
     * 获取招商引资_省库项目_省外投资单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzSkSwtzdwService.selectZsyzSkSwtzdwById(id));
    }

    /**
     * 新增招商引资_省库项目_省外投资单位
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:add')")
    @Log(title = "招商引资_省库项目_省外投资单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        return toAjax(zsyzSkSwtzdwService.insertZsyzSkSwtzdw(zsyzSkSwtzdw));
    }

    /**
     * 修改招商引资_省库项目_省外投资单位
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:edit')")
    @Log(title = "招商引资_省库项目_省外投资单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZsyzSkSwtzdw zsyzSkSwtzdw)
    {
        return toAjax(zsyzSkSwtzdwService.updateZsyzSkSwtzdw(zsyzSkSwtzdw));
    }

    /**
     * 删除招商引资_省库项目_省外投资单位
     */
    @PreAuthorize("@ss.hasPermi('projectV2:swtzdw:remove')")
    @Log(title = "招商引资_省库项目_省外投资单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzSkSwtzdwService.deleteZsyzSkSwtzdwByIds(ids));
    }
}
